---
title: "An Introduction to the Objective-Subjective Scoring System"
date: "2021-04-14"
tags:
- blog
- misc
---

It's difficult to fairly judge anything in a manner free from bias. It's even more difficult to do it for abstract and creative works such as literature or stories, as your own personal enjoyment can greatly affect how you view the work and any flaws it might have. The **Objective-Subjective Scoring System (OS3)** attempts to remedy this issue by separating as much bias as possible.

<!-- excerpt -->

The primary feature of OS3 is that it assigns two scores to a certain work with a small scale: the *objective score* and the *subjective score*, both inclusively ranging from 0 to 3.

## The objective score

The objective score should be representative of a work's clear quality relative to other works and how "good" it is. It should be as free from bias as possible and should have clear, defined criteria so that the standard can be consistently applied to other works. Ideally, an objective score should not be controversial and others who consume the same work should assign the same score. A sample criteria which I use for stories is provided below:

- **0:** The story does not meet expectations and contains large character, story, and/or formatting flaws that severely detract from the experience of the story, or worse. The story is *rejected objectively*.
- **1:** The story nearly fails to meets expectations and contains large character, story, and/or formatting flaws that severely detract from the experience of the story.
- **2:** The story meets expectations but contains flaws that do not severely detract from the. experience of the story.
- **3:** The story meets expectations and may contain flaws that do not detract from the experience of the story, or better.

The objective score is relative. To provide a meaningful score, there are only four options so it is easier to assign a certain score. Most typical stories should fall under an objective one or two. To reduce the influence of opinions on the objective score, it should be determined after the subjective score.

## The subjective score

The subjective score is…subjective. It should reflect your personal enjoyment of a work. Similar to the objective score, it should be kept consistent — a work with a subjective three should be without question to be more preferred than one with a subjective two. Clear and defined criteria are helpful here, but not as required as like in determining an objective score. A sample criteria which I use for stories is proided below:

- **0:** The story is not enjoyable and was dropped before completion. The story is *rejected subjectively*.
- **1:** The story is mildly enjoyable and was completed but likely will not be re-consumed very often if at all.
- **2:** The story is enjoyable and will be re-consumed from time to time.
- **3:** The story is very enjoyable and will most certainly be re-consumed fairly often.

## Influences and limitations

The objective of the OS3 is to minimise the impact of the subjective score on the objective score. However, it does nothing to prevent the opposite — which is fine. How "good" a work is likely has a direct impact on your enjoyment of it, anyway. This creates an effect where low objective scores are commonly paired up with low subjective scores, and high objective scores more commonly have high subjective scores.

Although this system can reduce the influence on bias in determining the quality of a work, it is still ultimately up to you to enforce a strict standard and not award works higher objective scores due to liking them more. I've found myself that I've had to reduce objective scores multiple times typically after re-consuming a work and looking at it from a more critical angle.

Happy judging!